translate.misc.hash

Package translate :: Package misc :: Module hash |
[hide private]
[frames] | no frames]

# Source Code for Module translate.misc.hash

     1  #!/usr/bin/env python
     2  # -*- coding: utf-8 -*-
     3  #
     4  # Copyright 2008 Zuza Software Foundation
     5  #
     6  # This file is part of translate.
     7  #
     8  # This program is free software; you can redistribute it and/or modify
     9  # it under the terms of the GNU General Public License as published by
    10  # the Free Software Foundation; either version 2 of the License, or
    11  # (at your option) any later version.
    12  #
    13  # This program is distributed in the hope that it will be useful,
    14  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    15  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    16  # GNU General Public License for more details.
    17  #
    18  # You should have received a copy of the GNU General Public License
    19  # along with this program; if not, see <http://www.gnu.org/licenses/>.
    20
    21  """This module contains some temporary glue to make us work with md5 hashes on
    22  old and new versions of Python. The function md5_f() wraps whatever is
    23  available."""
    24
    25  try:
    26      import hashlib
    27      md5_f = hashlib.md5
    28  except ImportError:
    29      import md5
    30      md5_f = md5.new
    31